@@ -1,10 +1,12 @@
 package Acme::CPANAuthors::POE;
+BEGIN {
+  $Acme::CPANAuthors::POE::VERSION = '0.16';
+}
+
+#ABSTRACT: We are CPAN Authors of POE
 
 use strict;
 use warnings;
-use vars qw($VERSION);
-
-$VERSION = '0.14';
 
 use Acme::CPANAuthors::Register (
   AAR => q[Alessandro Ranellucci],
@@ -38,6 +40,7 @@ use Acme::CPANAuthors::Register (
   FLETCH => q[Mike Fletcher],
   FRODWITH => q[Paul Driver],
   GDSL => q[Sergey Skvortsov],
+  GETTY => q[Torsten Raudssus],
   GRAYKOT => q[Sergey Kotenko],
   GREGFAST => q[Greg Fast],
   GRODITI => q[Guillermo Roditi],
@@ -113,12 +116,18 @@ use Acme::CPANAuthors::Register (
 
 q[We are POEsters];
 
+
 __END__
+=pod
 
 =head1 NAME
 
 Acme::CPANAuthors::POE - We are CPAN Authors of POE
 
+=head1 VERSION
+
+version 0.16
+
 =head1 SYNOPSIS
 
     use Acme::CPANAuthors;
@@ -171,6 +180,7 @@ It is currently statically generated information, I hope to make it dynamic in t
   FLETCH => q[Mike Fletcher],
   FRODWITH => q[Paul Driver],
   GDSL => q[Sergey Skvortsov],
+  GETTY => q[Torsten Raudssus],
   GRAYKOT => q[Sergey Kotenko],
   GREGFAST => q[Greg Fast],
   GRODITI => q[Guillermo Roditi],
@@ -243,20 +253,22 @@ It is currently statically generated information, I hope to make it dynamic in t
   YBLUSSEAU => q[Yves Blusseau],
   ZOFFIX => q[Zoffix Znet],
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<Acme::CPANAuthors>
 
 L<POE>
 
+=head1 AUTHOR
+
+Chris Williams
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
